summaryrefslogtreecommitdiff
path: root/ace/Strategies_T.h
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>2001-06-02 20:02:17 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>2001-06-02 20:02:17 +0000
commit86766c70ff11cda712718506276b5596b7f438f8 (patch)
treedfb8ce57904209d9f94746664978dca15a49935a /ace/Strategies_T.h
parentf59f477f1d7824c2e237a9dd14402cd4ddebfed6 (diff)
downloadATCD-86766c70ff11cda712718506276b5596b7f438f8.tar.gz
ChangeLogTag:Sat Jun 2 13:05:20 2001 Douglas C. Schmidt <schmidt@tango.doc.wustl.edu>
Diffstat (limited to 'ace/Strategies_T.h')
-rw-r--r--ace/Strategies_T.h16
1 files changed, 11 insertions, 5 deletions
diff --git a/ace/Strategies_T.h b/ace/Strategies_T.h
index 673d45e0e71..15c4d859fc1 100644
--- a/ace/Strategies_T.h
+++ b/ace/Strategies_T.h
@@ -6,11 +6,10 @@
*
* $Id$
*
- * @author Doug Schmidt
+ * @author Douglas C. Schmidt <schmidt@cs.wustl.edu>
*/
//=============================================================================
-
#ifndef ACE_STRATEGIES_T_H
#define ACE_STRATEGIES_T_H
#include "ace/pre.h"
@@ -456,9 +455,10 @@ public:
int restart = 0,
ACE_Reactor *reactor = ACE_Reactor::instance ());
/// Initialize the <peer_acceptor_> with <local_addr>.
virtual int open (const ACE_PEER_ACCEPTOR_ADDR &local_addr,
- int restart = 0);
+ int reuse_addr = 0);
/// Return the underlying ACE_HANDLE of the <peer_acceptor_>.
virtual ACE_HANDLE get_handle (void) const;
@@ -481,10 +481,16 @@ public:
protected:
/// Factory that establishes connections passively.
- ACE_PEER_ACCEPTOR acceptor_;
+ ACE_PEER_ACCEPTOR peer_acceptor_;
/// Pointer to the reactor used by the Acceptor.
ACE_Reactor *reactor_;
+
+ /// Needed to reopen the socket if <accept> fails.
+ int reuse_addr_;
+
+ /// Needed to reopen the socket if <accept> fails.
+ ACE_PEER_ACCEPTOR_ADDR peer_acceptor_addr_;
};
/**
@@ -456,9 +455,10 @@ public:
int restart = 0,
ACE_Reactor *reactor = ACE_Reactor::instance ());
- /// Initialize the <peer_acceptor_> with <local_addr>.
+ /// Initialize the <peer_acceptor_> with <local_addr>, indicating
+ /// whether to <reuse_addr> if it's already in use.
virtual int open (const ACE_PEER_ACCEPTOR_ADDR &local_addr,